==> maven-script-interpreter-1.3-source-release.zip: maven-script-interpreter-1.3/src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptException.java <==
package org.apache.maven.shared.scriptinterpreter;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Common errors during script running.
 *
 * @author Slawomir Jaranowski
 * @since 1.3
 */
public class ScriptException
    extends Exception
{
    private static final long serialVersionUID = 4553276474852776472L;

    /**
     * Creates a new exception with the specified message and cause.
     *
     * @param message The message, may be <code>null</code>.
     * @param cause The cause, may be <code>null</code>.
     */
    public ScriptException( String message, Throwable cause )
    {
        super( message, cause );
    }

    ScriptException( String message )
    {
        super( message );
    }

    ScriptException( Throwable cause )
    {
        super( cause );
    }
}

==> maven-script-interpreter-1.6-source-release.zip: maven-script-interpreter-1.6/src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.shared.scriptinterpreter;

/**
 * Common errors during script running.
 *
 * @author Slawomir Jaranowski
 * @since 1.3
 */
public class ScriptException extends Exception {
    private static final long serialVersionUID = 4553276474852776472L;

    /**
     * Creates a new exception with the specified message and cause.
     *
     * @param message The message, may be <code>null</code>.
     * @param cause The cause, may be <code>null</code>.
     */
    public ScriptException(String message, Throwable cause) {
        super(message, cause);
    }

    ScriptException(String message) {
        super(message);
    }

    ScriptException(Throwable cause) {
        super(cause);
    }
}
